@@ -1,7 +1,13 @@
 package Mojolicious::Plugin::Notifications::HTML;
-use Mojo::Base 'Mojolicious::Plugin::Notifications::Engine';
+use Mojo::Base 'Mojolicious::Plugin';
+use Mojo::Collection 'c';
+use Mojo::ByteStream 'b';
 use Mojo::Util qw/xml_escape/;
 
+# Nothing to register - but establishes the plugin
+sub register {};
+
+
 # Notification method
 sub notifications {
   my ($self, $c, $notify_array) = @_;
@@ -13,7 +19,7 @@ sub notifications {
 	"</div>\n";
   };
 
-  return $c->b($html);
+  return b($html);
 };
 
 
@@ -28,7 +34,7 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::Notifications::HTML - Event Notifications using HTML
+Mojolicious::Plugin::Notifications::HTML - Event Notification using HTML
 
 
 =head1 SYNOPSIS
@@ -47,7 +53,21 @@ Mojolicious::Plugin::Notifications::HTML - Event Notifications using HTML
 This plugin is a simple notification engine for HTML.
 
 If it does not suit your needs, you can easily
-L<write your own engine|Mojolicious::Plugin::Notifications::Engine>.
+L<write your own engine|Mojolicious::Plugin::Notifications/Writing your own engine>.
+
+
+=head1 METHODS
+
+L<Mojolicious::Plugin::Notifications::HTML> inherits all methods
+from L<Mojolicious::Plugin> and implements the following new one.
+
+=head2 register
+
+  plugin Notifications => {
+    HTML => 1
+  };
+
+Called when registering the main plugin. No parameters are necessary.
 
 
 =head1 HELPERS
@@ -78,7 +98,7 @@ the notification type you passed.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2014, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the terms of the Artistic License version 2.0.
