@@ -1,18 +1,18 @@
 package Mojolicious::Plugin::Notifications::JSON;
-use Mojo::Base 'Mojolicious::Plugin::Notifications::Engine';
+use Mojo::Base 'Mojolicious::Plugin';
 
 has key => 'notifications';
 
 # Nothing to register
 sub register {
-  my ($plugin, $app, $param) = @_;
+  my ($plugin, $mojo, $param) = @_;
   $plugin->key($param->{key}) if $param->{key};
 };
 
 
 # Notification method
 sub notifications {
-  my ($self, $c, $notify_array, $rule, $json, %param) = @_;
+  my ($self, $c, $notify_array, $json, %param) = @_;
 
   my $key = $param{key} // $self->key;
 
@@ -55,7 +55,7 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::Notifications::JSON - Event Notifications in JSON
+Mojolicious::Plugin::Notifications::JSON - Event Notification in JSON
 
 
 =head1 SYNOPSIS
@@ -74,15 +74,13 @@ Mojolicious::Plugin::Notifications::JSON - Event Notifications in JSON
 This plugin is a simple notification engine for JSON.
 
 If it does not suit your needs, you can easily
-L<write your own engine|Mojolicious::Plugin::Notifications::Engine>.
+L<write your own engine|Mojolicious::Plugin::Notifications/Writing your own engine>.
 
 
 =head1 METHODS
 
 L<Mojolicious::Plugin::Notifications::JSON> inherits all methods
-from L<Mojolicious::Plugin::Notifications::Engine> and implements
-the following new one.
-
+from L<Mojolicious::Plugin> and implements the following new one.
 
 =head2 register
 
@@ -143,7 +141,7 @@ The name defaults to C<notifications>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2014, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the terms of the Artistic License version 2.0.
